@@ -1,3 +1,17 @@
+binaryTransform <- function(x, from, to){
+  if (missing(from)){
+    from <- sort(unique(c(unlist(x))))
+  }
+  if (length(from) != 2){
+    stop("Binary data required")
+  }
+  
+  x2 <- x
+  x2[x==from[1]] <- to[1]
+  x2[x==from[2]] <- to[2]
+  x2
+}
+
 LinTransform <- function(graph, thresholds, from = c(0L, 1L), to = c(-1L, 1L), a, b)
 {
   stopifnot(!missing(graph) & !missing(thresholds))
